IteratorServerHandler

Trait IteratorServerHandler 

pub trait IteratorServerHandler<___T = Channel>
where ___T: Transport,
{ // Required method fn get( &mut self, responder: Responder<Get, ___T>, ) -> impl Future<Output = ()> + Send; }
A server handler for the Iterator protocol.

See Iterator for more details.

Required Methods

fn get( &mut self, responder: Responder<Get, ___T>, ) -> impl Future<Output = ()> + Send

Gets the next batch of keys.

The client pulls keys rather than having the server proactively push them, to implement flow control over the messages.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors